'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var child_process = require('child_process');
var React = _interopDefault(require('react'));
var ink = require('ink');
var SelectInput = _interopDefault(require('ink-select-input'));
var TextInput = _interopDefault(require('ink-text-input'));
var fs = _interopDefault(require('fs'));
var fg = _interopDefault(require('fast-glob'));
var pick = _interopDefault(require('lodash/pick'));

// A type of promise-like that resolves synchronously and supports only one observer

const _iteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.iterator || (Symbol.iterator = Symbol("Symbol.iterator"))) : "@@iterator";

const _asyncIteratorSymbol = /*#__PURE__*/ typeof Symbol !== "undefined" ? (Symbol.asyncIterator || (Symbol.asyncIterator = Symbol("Symbol.asyncIterator"))) : "@@asyncIterator";

// Asynchronously call a function and send errors to recovery continuation
function _catch(body, recover) {
	try {
		var result = body();
	} catch(e) {
		return recover(e);
	}
	if (result && result.then) {
		return result.then(void 0, recover);
	}
	return result;
}

const readFile = function (file) {
  try {
    return Promise.resolve(JSON.parse(fs.readFileSync(file, "utf8")));
  } catch (e) {
    return Promise.reject(e);
  }
};

const findPackages = () => fg.sync("**/package.json", {
  ignore: ["**/node_modules/**"]
});
const findWorkspaces = function () {
  try {
    function _temp2() {
      return results.reduce((acc, result, index) => {
        const p = packages[index];
        acc[p] = pick(result, ["name", "version", "scripts"]);
        return acc;
      }, {});
    }

    const packages = findPackages();
    let results;

    const _temp = _catch(function () {
      return Promise.resolve(Promise.all(packages.map(p => readFile(p)))).then(function (_Promise$all) {
        results = _Promise$all;
      });
    }, function () {
      console.log("\x1b[31m", "Error: Unable to process projects..");
      process.exit(1);
    });

    return Promise.resolve(_temp && _temp.then ? _temp.then(_temp2) : _temp2(_temp));
  } catch (e) {
    return Promise.reject(e);
  }
};
const composeItems = function () {
  try {
    return Promise.resolve(findWorkspaces()).then(function (workspaces) {
      const items = [];
      Object.entries(workspaces).forEach(([location, packageContent]) => {
        let isRoot = location === "package.json" ? true : false;
        const runCmd = `yarn ${!isRoot ? `workspace ${packageContent.name} ` : ""}run`;
        items.push({
          label: packageContent.name,
          value: runCmd,
          preview: runCmd,
          divider: true,
          location
        });

        if (packageContent.scripts) {
          Object.entries(packageContent.scripts).forEach(([script]) => {
            const scriptCmd = `yarn ${!isRoot ? `workspace ${packageContent.name} ` : ""}run ${script}`;
            items.push({
              label: scriptCmd,
              value: scriptCmd,
              preview: packageContent.scripts[script]
            });
          });
        }
      });
      return items;
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

const fuzzySearch = (needle = "", haystack = "") => {
  const nlen = needle.length;
  const hlen = haystack.length;
  if (nlen > hlen) return false;
  if (nlen === hlen) return needle === haystack;

  outer: for (let i = 0, j = 0; i < nlen; i++) {
    const nch = needle.charCodeAt(i);

    while (j < hlen) {
      if (haystack.charCodeAt(j++) === nch) {
        continue outer;
      }
    }

    return false;
  }

  return true;
};

const filterItems = (text, items = []) => items.filter(item => fuzzySearch(text, item.label) || fuzzySearch(text, item.value) || fuzzySearch(text, item.preview));

const NpmScript = props => {
  const {
    label,
    divider,
    preview,
    location
  } = props;

  if (divider) {
    return React.createElement(Divider, {
      location: location,
      preview: preview
    }, label);
  }

  return React.createElement(ink.Box, {
    flexDirection: "column"
  }, React.createElement(ink.Text, null, React.createElement(ink.Color, {
    green: true
  }, " ", label, " ")), preview && React.createElement(ink.Box, null, React.createElement(ink.Text, null, " ", React.createElement(ink.Color, {
    gray: true
  }, " \u21B3 ", preview, " "))));
};

const Divider = ({
  children,
  location,
  preview
}) => React.createElement(ink.Box, {
  flexDirection: "column",
  flexGrow: 1
}, React.createElement(ink.Box, {
  flexDirection: "row",
  flexGrow: 1,
  justifyContent: "space-between"
}, React.createElement(ink.Box, null, React.createElement(ink.Color, {
  cyan: true
}, React.createElement(ink.Text, {
  bold: true,
  underline: true
}, children)), React.createElement(ink.Color, {
  gray: true
}, " \u21E2 ", preview, " ")), React.createElement(ink.Box, null, React.createElement(ink.Color, {
  blue: true
}, location, " "))));

const App = ({
  flags
}) => {
  const terminalHeight = Number(flags.limit) || 10;
  const [limit, setLimit] = React.useState(terminalHeight);
  const [step, setStep] = React.useState(0);
  const [cmd, setCmd] = React.useState("");
  const [query, setQuery] = React.useState("");
  const [items, setItems] = React.useState([]);
  React.useEffect(() => {
    const getWorkspaces = function () {
      try {
        return Promise.resolve(composeItems()).then(function (items) {
          setItems(items);
          setLimit(Math.floor(Math.min(items.length, terminalHeight)));
        });
      } catch (e) {
        return Promise.reject(e);
      }
    };

    getWorkspaces();
  }, []);
  return React.createElement(ink.Box, {
    flexDirection: "column"
  }, React.createElement(ink.Box, null, React.createElement(ink.Text, {
    bold: true
  }, "Which command do you want to run?"), " ", React.createElement(ink.Color, {
    green: true
  }, step === 0 && React.createElement(TextInput, {
    value: query,
    onChange: value => setQuery(value)
  }), step === 1 ? React.createElement(TextInput, {
    value: cmd,
    onChange: value => setCmd(value),
    onSubmit: value => {
      setStep(2);

      if (flags.copy) {
        const proc = child_process.spawn("pbcopy");
        proc.stdin.write(value);
        proc.stdin.end();
        process.exit(0);
      } else {
        try {
          child_process.execSync(value, {
            stdio: "inherit"
          });
        } catch (err) {
          process.exit(0);
        }
      }
    }
  }) : cmd)), step === 0 && React.createElement(SelectInput, {
    limit: limit,
    items: filterItems(query, items),
    itemComponent: NpmScript,
    onSelect: item => {
      setCmd(`${item.value} `);
      setStep(1);
    }
  }));
};

const renderApp = flags => ink.render(React.createElement(App, {
  flags: flags
}));

exports.renderApp = renderApp;
//# sourceMappingURL=yex.cjs.development.js.map
